@@ -27,6 +27,15 @@ has '+do_while' => (
 has managed_schema  => ( is => 'ro', isa => Str, default => 'public' );
 has tracking_schema => ( is => 'ro', isa => Str, default => 'public' );
 
+sub create_tracking_table {
+  my $self = shift;
+
+  my $tracking_schema = $self->dbh->quote_identifier( $self->tracking_schema );
+  $Logger->debugf( "Create tracking schema '%s'", $tracking_schema );
+  $self->dbh->do( "CREATE SCHEMA IF NOT EXISTS $tracking_schema" );
+  $self->SUPER::create_tracking_table;
+}
+
 sub quoted_tracking_table {
   my $self = shift;
 
